@@ -77,7 +77,7 @@ K2 <- K2(S=S, T=T, P=P, pHscale=pHscale, k1k2=k1k2[i])
 Kf <- Kf(S=S, T=T, P=P, pHscale=pHscale, kf=kf[i])
 Ks <- Ks(S=S, T=T, P=P, ks=ks[i])
 Kw <- Kw(S=S, T=T, P=P, pHscale=pHscale)
-Kh <- Kh(S=S, T=T, P=P)
+K0 <- K0(S=S, T=T, P=P)
 Kb <- Kb(S=S, T=T, P=P, pHscale=pHscale)
 K1p <- K1p(S=S, T=T, P=P, pHscale=pHscale)
 K2p <- K2p(S=S, T=T, P=P, pHscale=pHscale)
@@ -122,7 +122,7 @@ rho <- rho(S=S,T=T,P=P)
 	PH <- var1
 	CO2 <- var2
 	h <- 10^(-PH)
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	HCO3 <- (K1*CO2)/h
 	CO3 <- (K2*HCO3)/h
 	DIC <- CO2 + HCO3 + CO3
@@ -133,9 +133,9 @@ rho <- rho(S=S,T=T,P=P)
 	{
 	CO2 <- var1
 	HCO3 <- var2
-	fCO2 <- CO2/Kh
-	h <- Kh*K1*fCO2/HCO3
-	CO3 <- Kh*K1*K2*fCO2/(h*h)
+	fCO2 <- CO2/K0
+	h <- K0*K1*fCO2/HCO3
+	CO3 <- K0*K1*K2*fCO2/(h*h)
 	DIC <- CO2 + HCO3 + CO3
 	PH <- -log10(h)
 	}
@@ -145,9 +145,9 @@ rho <- rho(S=S,T=T,P=P)
 	{
 	CO2 <- var1
 	CO3 <- var2
-	fCO2 <- CO2/Kh
-	h <- sqrt((Kh*K1*K2*fCO2)/CO3)
-	HCO3 <- (Kh*K1*fCO2)/h
+	fCO2 <- CO2/K0
+	h <- sqrt((K0*K1*K2*fCO2)/CO3)
+	HCO3 <- (K0*K1*fCO2)/h
 	DIC <- CO2 + HCO3 + CO3
 	PH <- -log10(h)
 	}
@@ -160,6 +160,7 @@ rho <- rho(S=S,T=T,P=P)
 	ALK <- var2
 	fALK <- function(x)# K1=K1, K2=K2, CO2=CO2, bor=bor, Kb=Kb, Kw=Kw, Pt=Pt, K1p=K1p, K2p=K2p, K3p=K3p, Sit=Sit, Ksi=Ksi, NH3t=NH3t, KNH3=KNH3, H2St=H2St, KH2S=KH2S, ST=ST, Ks=Ks, fluo=fluo, Kf=Kf, ALK=ALK) {
 	# composants for ALK
+# x is the H+concentration
 	{DIC <- CO2*(1+K1/x+K1*K2/(x*x))
 	hco3 <- DIC*x*K1/(x*x + K1*x + K1*K2)
 	co3 <- DIC*K1*K2/(x*x + K1*x + K1*K2)
@@ -189,7 +190,7 @@ rho <- rho(S=S,T=T,P=P)
 	DIC <- CO2*(1+K1/h+K1*K2/(h*h))
 	HCO3 <- (DIC*K1*h)/(h*h+K1*h+K1*K2)
 	CO3 <- (DIC*K1*K2)/(h*h+K1*h+K1*K2)
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	PH <- -log10(h)
 	}
 
@@ -198,14 +199,14 @@ rho <- rho(S=S,T=T,P=P)
 	{
 	CO2 <- var1
 	DIC <- var2
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	a <- K1*K2*CO2
 	b <- K1*CO2
 	c <- CO2 - DIC
 	D <- b*b - 4*a*c
 	X <- (sqrt(D)-b)/(2*a)  # X = 1/h
 	h <- 2*K1*K2*CO2/(sqrt(K1*CO2*K1*CO2 - 4*K1*K2*CO2*(CO2 - DIC))-K1*CO2)
-	HCO3 <- Kh*K1*fCO2/h
+	HCO3 <- K0*K1*fCO2/h
 	CO3 <- DIC - CO2 - HCO3
 	PH <- -log10(h)
 	}
@@ -219,7 +220,7 @@ rho <- rho(S=S,T=T,P=P)
 	CO2 <- (HCO3*h)/K1
 	CO3 <- K2*HCO3/h
 	DIC <- CO2 + HCO3 + CO3
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	}
 
 	# ------------ case 7.) PH and CO3 given	
@@ -230,7 +231,7 @@ rho <- rho(S=S,T=T,P=P)
 	h <- 10^(-PH)
 	HCO3 <- CO3*h/K2
 	CO2 <- HCO3*h/K1
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	DIC <- CO2 + HCO3 + CO3
 	}
 
@@ -267,7 +268,7 @@ rho <- rho(S=S,T=T,P=P)
 	CO2 <- DIC/(1+K1/h+K1*K2/(h^2))
 	HCO3 <- CO2*K1/h
 	CO3 <- HCO3*K2/h
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	}
 	
 	# ------------ case 9.) PH and DIC given
@@ -279,7 +280,7 @@ rho <- rho(S=S,T=T,P=P)
 	HCO3 <- (DIC*K1*h)/(h*h+K1*h+K1*K2)
 	CO3 <- (DIC*K1*K2)/(h*h+K1*h+K1*K2)
 	CO2 <- h*HCO3/K1
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	}
 	
 	# ------------ case 10.) HCO3 and CO3 given	
@@ -290,7 +291,7 @@ rho <- rho(S=S,T=T,P=P)
 	h <- K2*HCO3/CO3
 	CO2 <- h*HCO3/K1
 	DIC <- CO2 + HCO3 + CO3
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	PH <- -log10(h)
 	}
 
@@ -332,7 +333,7 @@ rho <- rho(S=S,T=T,P=P)
 	CO3 <- K2*HCO3/h
 	DIC <- CO2 + HCO3 + CO3
 	PH <- -log10(h)
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	}
 
 	# ------------ case 12.) HCO3 and DIC given
@@ -347,7 +348,7 @@ rho <- rho(S=S,T=T,P=P)
 	h <- (-b-sqrt(D))/(2*a)
 	CO2 <- h*HCO3/K1
 	CO3 <- K2*HCO3/h
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	PH <- -log10(h)
 	}
 
@@ -387,7 +388,7 @@ rho <- rho(S=S,T=T,P=P)
 	
  	HCO3 <- h*CO3/K2
 	CO2 <- h*HCO3/K1
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	DIC <- HCO3+CO2+CO3
 	PH <- -log10(h)
 	}
@@ -400,7 +401,7 @@ rho <- rho(S=S,T=T,P=P)
 	h <- (-K1*CO3 + sqrt(((K1*CO3)^2)-4*CO3*K1*K2*(CO3-DIC)))/(2*CO3)
 	HCO3 <- h*CO3/K2
 	CO2 <- h*HCO3/K1
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	PH <- -log10(h)
 	}
 	
@@ -441,7 +442,7 @@ rho <- rho(S=S,T=T,P=P)
 	HCO3 <- (DIC*K1*h)/(h*h+K1*h+K1*K2)
 	CO3 <- (DIC*K1*K2)/(h*h+K1*h+K1*K2)
 	CO2 <- h*HCO3/K1
-	fCO2 <- CO2/Kh
+	fCO2 <- CO2/K0
 	PH <- -log10(h)
 	}
 
@@ -469,7 +470,7 @@ rho <- rho(S=S,T=T,P=P)
 	{
 	PH <- var2
 	h <- 10^(-PH)
-	CO2 <- Kh*fCO2
+	CO2 <- K0*fCO2
 	HCO3 <- K1*CO2/h
 	CO3 <- K2*HCO3/h
 	DIC <- CO2 + HCO3 + CO3
@@ -479,7 +480,7 @@ rho <- rho(S=S,T=T,P=P)
 	if (flag==22)
 	{
 	HCO3 <- var2
-	CO2 <- fCO2*Kh
+	CO2 <- fCO2*K0
 	h <- CO2*K1/HCO3
 	CO3 <- HCO3*K2/h
 	DIC <- CO2 + HCO3 + CO3
@@ -490,7 +491,7 @@ rho <- rho(S=S,T=T,P=P)
 	if (flag==23)
 	{
 	CO3 <- var2
-	h <- sqrt(Kh*K1*K2*fCO2/CO3)
+	h <- sqrt(K0*K1*K2*fCO2/CO3)
 	HCO3 <- h*CO3/K2
 	CO2 <- h*HCO3/K1
 	DIC <- CO2 + HCO3 + CO3
@@ -501,7 +502,7 @@ rho <- rho(S=S,T=T,P=P)
 	if (flag==24)
 	{
 	ALK <- var2
-	CO2 <- fCO2*Kh
+	CO2 <- fCO2*K0
 
 	fALK <- function(x)# K1=K1, K2=K2, CO2=CO2, bor=bor, Kb=Kb, Kw=Kw, Pt=Pt, K1p=K1p, K2p=K2p, K3p=K3p, Sit=Sit, Ksi=Ksi, NH3t=NH3t, KNH3=KNH3, H2St=H2St, KH2S=KH2S, ST=ST, Ks=Ks, fluo=fluo, Kf=Kf, ALK=ALK) {
 	# composants for ALK
@@ -542,9 +543,9 @@ rho <- rho(S=S,T=T,P=P)
 	if (flag==25)
 	{
 	DIC <- var2
-	CO2 <- Kh*fCO2
+	CO2 <- K0*fCO2
 	K <- K1/K2
-	HCO3 <- (1/2)*(-K*Kh*fCO2+sqrt((K*Kh*fCO2)^2 - 4*(K*Kh*fCO2)*(Kh*fCO2-DIC)))
+	HCO3 <- (1/2)*(-K*K0*fCO2+sqrt((K*K0*fCO2)^2 - 4*(K*K0*fCO2)*(K0*fCO2-DIC)))
 	CO3 <- DIC - CO2 - HCO3
 	h <- K1*CO2/HCO3
 	PH <- -log10(h)
